/*
 * Copyright (c) 2002-2003 iReasoning Inc. All Rights Reserved.
 * 
 * This SOURCE CODE FILE, which has been provided by iReasoning Inc. as part
 * of an iReasoning Software product for use ONLY by licensed users of the product,
 * includes CONFIDENTIAL and PROPRIETARY information of iReasoning Inc.  
 *
 * USE OF THIS SOFTWARE IS GOVERNED BY THE TERMS AND CONDITIONS 
 * OF THE LICENSE STATEMENT AND LIMITED WARRANTY FURNISHED WITH
 * THE PRODUCT.
 *
 * IN PARTICULAR, YOU WILL INDEMNIFY AND HOLD IREASONING SOFTWARE, ITS
 * RELATED COMPANIES AND ITS SUPPLIERS, HARMLESS FROM AND AGAINST ANY
 * CLAIMS OR LIABILITIES ARISING OUT OF THE USE, REPRODUCTION, OR
 * DISTRIBUTION OF YOUR PROGRAMS, INCLUDING ANY CLAIMS OR LIABILITIES
 * ARISING OUT OF OR RESULTING FROM THE USE, MODIFICATION, OR
 * DISTRIBUTION OF PROGRAMS OR FILES CREATED FROM, BASED ON, AND/OR
 * DERIVED FROM THIS SOURCE CODE FILE.
 */

package agent.ifmib;
import java.io.*;
import java.util.*;
import com.ireasoning.util.*;
import com.ireasoning.protocol.snmp.*;
import javax.management.*;

/**
 * Table entry class
 */
public class IfStackEntry extends SnmpTableEntry
{
    // SnmpOID: .1.3.6.1.2.1.31.1.2.1.1
    protected int _ifStackHigherLayer = 0;
    // SnmpOID: .1.3.6.1.2.1.31.1.2.1.2
    protected int _ifStackLowerLayer = 0;
    // SnmpOID: .1.3.6.1.2.1.31.1.2.1.3
    protected int _ifStackStatus = 0;
    
    /**
     * Constructor
     * @param table the Table which contains this table entry class
     */
    public IfStackEntry(SnmpTable table)
    {
        super(table);
    }
    
    /**
     * Constructor. Initializes member variables
     * @param table the Table which contains this table entry class
     */
    public IfStackEntry( SnmpTable table, int ifStackHigherLayer, int ifStackLowerLayer, int ifStackStatus)
    {
        super(table);
        
        this._ifStackHigherLayer = ifStackHigherLayer;
        this._ifStackLowerLayer = ifStackLowerLayer;
        this._ifStackStatus = ifStackStatus;
        
    }
    
    /**
     * Returns the index string for this row
     * @return the index string for this row. Return null to indicate that this row will not be added
     */
    public String getIndexSuffix()
    {
        if(_suffix.length() == 0)
        {
            _suffix = "." + SnmpTableEntry.getIndexString("" + _ifStackHigherLayer, false) + "." + SnmpTableEntry.getIndexString("" + _ifStackLowerLayer, false);
        }
        return _suffix;
    }
    
    /**
     * Sets column value at specified index
     * @param index the index of column to be set new value
     * @param value new value of the column
     */
    public void set(int index, SnmpDataType value)
    {
        switch(index)
        {
            case 0 :
            _ifStackHigherLayer = ((SnmpInt) value).getValue();
            break;
            case 1 :
            _ifStackLowerLayer = ((SnmpInt) value).getValue();
            break;
            case 2 :
            _ifStackStatus = ((SnmpInt) value).getValue();
            break;
        }
    }
    
}
