/*
 * Copyright (c) 2002-2003 iReasoning Inc. All Rights Reserved.
 * 
 * This SOURCE CODE FILE, which has been provided by iReasoning Inc. as part
 * of an iReasoning Software product for use ONLY by licensed users of the product,
 * includes CONFIDENTIAL and PROPRIETARY information of iReasoning Inc.  
 *
 * USE OF THIS SOFTWARE IS GOVERNED BY THE TERMS AND CONDITIONS 
 * OF THE LICENSE STATEMENT AND LIMITED WARRANTY FURNISHED WITH
 * THE PRODUCT.
 *
 * IN PARTICULAR, YOU WILL INDEMNIFY AND HOLD IREASONING SOFTWARE, ITS
 * RELATED COMPANIES AND ITS SUPPLIERS, HARMLESS FROM AND AGAINST ANY
 * CLAIMS OR LIABILITIES ARISING OUT OF THE USE, REPRODUCTION, OR
 * DISTRIBUTION OF YOUR PROGRAMS, INCLUDING ANY CLAIMS OR LIABILITIES
 * ARISING OUT OF OR RESULTING FROM THE USE, MODIFICATION, OR
 * DISTRIBUTION OF PROGRAMS OR FILES CREATED FROM, BASED ON, AND/OR
 * DERIVED FROM THIS SOURCE CODE FILE.
 */

package agent.ifmib;
import java.io.*;
import java.util.*;
import com.ireasoning.util.*;
import com.ireasoning.protocol.snmp.*;
import javax.management.*;

/**
 * Interface represents ifXTable MIB object in IF_MIB
 */
public interface IfXTableMBean extends SnmpTableMBean
{
    /**
     * Gets ifName value
     * @param ifXEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public String getIfName(SnmpTableEntry ifXEntry, SnmpPdu pdu);
    
    /**
     * Gets ifInMulticastPkts value
     * @param ifXEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter32 getIfInMulticastPkts(SnmpTableEntry ifXEntry, SnmpPdu pdu);
    
    /**
     * Gets ifInBroadcastPkts value
     * @param ifXEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter32 getIfInBroadcastPkts(SnmpTableEntry ifXEntry, SnmpPdu pdu);
    
    /**
     * Gets ifOutMulticastPkts value
     * @param ifXEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter32 getIfOutMulticastPkts(SnmpTableEntry ifXEntry, SnmpPdu pdu);
    
    /**
     * Gets ifOutBroadcastPkts value
     * @param ifXEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter32 getIfOutBroadcastPkts(SnmpTableEntry ifXEntry, SnmpPdu pdu);
    
    /**
     * Gets ifHCInOctets value
     * @param ifXEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter64 getIfHCInOctets(SnmpTableEntry ifXEntry, SnmpPdu pdu);
    
    /**
     * Gets ifHCInUcastPkts value
     * @param ifXEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter64 getIfHCInUcastPkts(SnmpTableEntry ifXEntry, SnmpPdu pdu);
    
    /**
     * Gets ifHCInMulticastPkts value
     * @param ifXEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter64 getIfHCInMulticastPkts(SnmpTableEntry ifXEntry, SnmpPdu pdu);
    
    /**
     * Gets ifHCInBroadcastPkts value
     * @param ifXEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter64 getIfHCInBroadcastPkts(SnmpTableEntry ifXEntry, SnmpPdu pdu);
    
    /**
     * Gets ifHCOutOctets value
     * @param ifXEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter64 getIfHCOutOctets(SnmpTableEntry ifXEntry, SnmpPdu pdu);
    
    /**
     * Gets ifHCOutUcastPkts value
     * @param ifXEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter64 getIfHCOutUcastPkts(SnmpTableEntry ifXEntry, SnmpPdu pdu);
    
    /**
     * Gets ifHCOutMulticastPkts value
     * @param ifXEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter64 getIfHCOutMulticastPkts(SnmpTableEntry ifXEntry, SnmpPdu pdu);
    
    /**
     * Gets ifHCOutBroadcastPkts value
     * @param ifXEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter64 getIfHCOutBroadcastPkts(SnmpTableEntry ifXEntry, SnmpPdu pdu);
    
    /**
     * Gets ifLinkUpDownTrapEnable value
     * @param ifXEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public int getIfLinkUpDownTrapEnable(SnmpTableEntry ifXEntry, SnmpPdu pdu);
    
    /**
     * Sets new ifLinkUpDownTrapEnable value
     * @param ifXEntry table entry object
     * @param newValue new value to be set
     * @param pdu the received SnmpPdu object
     */
    public void setIfLinkUpDownTrapEnableValue(SnmpTableEntry ifXEntry, Object newValue, SnmpPdu pdu);
    
    /**
     * Gets ifHighSpeed value
     * @param ifXEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpGauge32 getIfHighSpeed(SnmpTableEntry ifXEntry, SnmpPdu pdu);
    
    /**
     * Gets ifPromiscuousMode value
     * @param ifXEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public int getIfPromiscuousMode(SnmpTableEntry ifXEntry, SnmpPdu pdu);
    
    /**
     * Sets new ifPromiscuousMode value
     * @param ifXEntry table entry object
     * @param newValue new value to be set
     * @param pdu the received SnmpPdu object
     */
    public void setIfPromiscuousModeValue(SnmpTableEntry ifXEntry, Object newValue, SnmpPdu pdu);
    
    /**
     * Gets ifConnectorPresent value
     * @param ifXEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public int getIfConnectorPresent(SnmpTableEntry ifXEntry, SnmpPdu pdu);
    
    /**
     * Gets ifAlias value
     * @param ifXEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public String getIfAlias(SnmpTableEntry ifXEntry, SnmpPdu pdu);
    
    /**
     * Sets new ifAlias value
     * @param ifXEntry table entry object
     * @param newValue new value to be set
     * @param pdu the received SnmpPdu object
     */
    public void setIfAliasValue(SnmpTableEntry ifXEntry, Object newValue, SnmpPdu pdu);
    
}
