/*
 * Copyright (c) 2002-2003 iReasoning Inc. All Rights Reserved.
 * 
 * This SOURCE CODE FILE, which has been provided by iReasoning Inc. as part
 * of an iReasoning Software product for use ONLY by licensed users of the product,
 * includes CONFIDENTIAL and PROPRIETARY information of iReasoning Inc.  
 *
 * USE OF THIS SOFTWARE IS GOVERNED BY THE TERMS AND CONDITIONS 
 * OF THE LICENSE STATEMENT AND LIMITED WARRANTY FURNISHED WITH
 * THE PRODUCT.
 *
 * IN PARTICULAR, YOU WILL INDEMNIFY AND HOLD IREASONING SOFTWARE, ITS
 * RELATED COMPANIES AND ITS SUPPLIERS, HARMLESS FROM AND AGAINST ANY
 * CLAIMS OR LIABILITIES ARISING OUT OF THE USE, REPRODUCTION, OR
 * DISTRIBUTION OF YOUR PROGRAMS, INCLUDING ANY CLAIMS OR LIABILITIES
 * ARISING OUT OF OR RESULTING FROM THE USE, MODIFICATION, OR
 * DISTRIBUTION OF PROGRAMS OR FILES CREATED FROM, BASED ON, AND/OR
 * DERIVED FROM THIS SOURCE CODE FILE.
 */

package agent.master;
import java.io.*;
import java.util.*;
import com.ireasoning.util.*;
import com.ireasoning.protocol.snmp.*;
import javax.management.*;

/**
 * Interface represents ifTable MIB object in IF_MIB
 */
public interface IfTableMBean extends SnmpTableMBean
{
    /**
     * Gets ifIndex value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public int getIfIndex(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Gets ifDescr value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public String getIfDescr(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Gets ifType value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public int getIfType(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Gets ifMtu value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public int getIfMtu(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Gets ifSpeed value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpGauge32 getIfSpeed(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Gets ifPhysAddress value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public String getIfPhysAddress(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Gets ifAdminStatus value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public int getIfAdminStatus(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Sets new ifAdminStatus value
     * @param ifEntry table entry object
     * @param newValue new value to be set
     * @param pdu the received SnmpPdu object
     */
    public void setIfAdminStatusValue(SnmpTableEntry ifEntry, Object newValue, SnmpPdu pdu);
    
    /**
     * Gets ifOperStatus value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public int getIfOperStatus(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Gets ifLastChange value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpTimeTicks getIfLastChange(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Gets ifInOctets value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter32 getIfInOctets(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Gets ifInUcastPkts value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter32 getIfInUcastPkts(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Gets ifInNUcastPkts value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter32 getIfInNUcastPkts(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Gets ifInDiscards value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter32 getIfInDiscards(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Gets ifInErrors value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter32 getIfInErrors(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Gets ifInUnknownProtos value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter32 getIfInUnknownProtos(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Gets ifOutOctets value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter32 getIfOutOctets(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Gets ifOutUcastPkts value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter32 getIfOutUcastPkts(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Gets ifOutNUcastPkts value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter32 getIfOutNUcastPkts(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Gets ifOutDiscards value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter32 getIfOutDiscards(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Gets ifOutErrors value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpCounter32 getIfOutErrors(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Gets ifOutQLen value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpGauge32 getIfOutQLen(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
    /**
     * Gets ifSpecific value
     * @param ifEntry table entry object
     * @param pdu the received SnmpPdu object
     */
    public SnmpOID getIfSpecific(SnmpTableEntry ifEntry, SnmpPdu pdu);
    
}
